@@ -57,8 +57,8 @@ class ViewGeneralMethods:
                 self.generic_create(model, data)
             else:
                 action_text = 'updated'
-                model_object = self.db.get_or_404(model, object_id)
-                self.generic_update(model_object, data)
+                model_object = model.query.get_or_404(object_id)
+                self.generic_update(model_object.to_json(), data)
             self.db.session.commit()
         except ValueError:
             self.db.session.rollback()
@@ -83,7 +83,7 @@ class ViewGeneralMethods:
         :param model_object:
         :return:
         """
-        model_object.update_from_json(data)
+        model_object.query.filter_by(id=model_object.id).update(data)
 
     def generic_details(self, model, schema, object_id):
         """
